@@ -242,11 +242,17 @@ We recommend you store the image in Tencent Cloud, as a Tencent Cloud URL can gu
         :type IsWords: bool
         :param EnableDetectSplit: Whether to slice the input image to enhance the recognition effects for scenarios where the whole image is big, but the size of a single character is small (e.g., test papers). This feature is disabled by default.
         :type EnableDetectSplit: bool
+        :param IsPdf: Whether to enable PDF recognition. Default value: `false`. If you enable this feature, both images and PDF files can be recognized.
+        :type IsPdf: bool
+        :param PdfPageNumber: Number of a PDF page that needs to be recognized. Currently, only one single page can be recognized. This parameter takes effect only if a PDF file is uploaded and `IsPdf` is set to `true`. Default value: `1`
+        :type PdfPageNumber: int
         """
         self.ImageBase64 = None
         self.ImageUrl = None
         self.IsWords = None
         self.EnableDetectSplit = None
+        self.IsPdf = None
+        self.PdfPageNumber = None
 
 
     def _deserialize(self, params):
@@ -254,6 +260,8 @@ We recommend you store the image in Tencent Cloud, as a Tencent Cloud URL can gu
         self.ImageUrl = params.get("ImageUrl")
         self.IsWords = params.get("IsWords")
         self.EnableDetectSplit = params.get("EnableDetectSplit")
+        self.IsPdf = params.get("IsPdf")
+        self.PdfPageNumber = params.get("PdfPageNumber")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -418,9 +426,9 @@ class HKIDCardOCRRequest(AbstractModel):
         :type DetectFake: bool
         :param ReturnHeadImage: Whether to return identity photo.
         :type ReturnHeadImage: bool
-        :param ImageBase64: Base64-encoded value of image.
-Supported image formats: PNG, JPG, JPEG. GIF is currently not supported.
-Supported image size: the downloaded image cannot exceed 3 MB in size after being Base64-encoded. The download time of the image cannot exceed 3 seconds.
+        :param ImageBase64: Base64 string of the image
+Supported image formats: PNG, JPG, JPEG. GIF is not supported yet.
+Supported image size: The downloaded image cannot exceed 7 MB after being Base64-encoded, and it cannot take longer than 3 seconds to download the image.
         :type ImageBase64: str
         :param ImageUrl: URL address of image. (This field is not supported outside Chinese mainland)
 Supported image formats: PNG, JPG, JPEG. GIF is currently not supported.
