@@ -23,6 +23,9 @@ FAILEDOPERATION_APIGATEWAY = 'FailedOperation.ApiGateway'
 # Failed to create the trigger.
 FAILEDOPERATION_APIGW = 'FailedOperation.Apigw'
 
+# Failed to obtain Apm InstanceId
+FAILEDOPERATION_APMCONFIGINSTANCEID = 'FailedOperation.ApmConfigInstanceId'
+
 # This operation is not supported by the current async event status. Please try again later.
 FAILEDOPERATION_ASYNCEVENTSTATUS = 'FailedOperation.AsyncEventStatus'
 
@@ -98,10 +101,10 @@ FAILEDOPERATION_OPENSERVICE = 'FailedOperation.OpenService'
 # Operation conflict.
 FAILEDOPERATION_OPERATIONCONFLICT = 'FailedOperation.OperationConflict'
 
-# 
+# Failed to create the scheduled provisioned concurrency scaling action
 FAILEDOPERATION_PROVISIONCREATETIMER = 'FailedOperation.ProvisionCreateTimer'
 
-# 
+# Failed to delete the scheduled provisioned concurrency scaling action
 FAILEDOPERATION_PROVISIONDELETETIMER = 'FailedOperation.ProvisionDeleteTimer'
 
 # The function version already has a provisioned concurrency setting task in progress. Please try again later.
@@ -191,6 +194,15 @@ INVALIDPARAMETERVALUE_ALIAS = 'InvalidParameterValue.Alias'
 # ApiGateway parameter error.
 INVALIDPARAMETERVALUE_APIGATEWAY = 'InvalidParameterValue.ApiGateway'
 
+# ApmConfig input error
+INVALIDPARAMETERVALUE_APMCONFIG = 'InvalidParameterValue.ApmConfig'
+
+# ApmConfigInstanceId input error
+INVALIDPARAMETERVALUE_APMCONFIGINSTANCEID = 'InvalidParameterValue.ApmConfigInstanceId'
+
+# ApmConfigRegion input error
+INVALIDPARAMETERVALUE_APMCONFIGREGION = 'InvalidParameterValue.ApmConfigRegion'
+
 # The parameter for async retry configuration of the function is invalid.
 INVALIDPARAMETERVALUE_ASYNCTRIGGERCONFIG = 'InvalidParameterValue.AsyncTriggerConfig'
 
@@ -350,16 +362,16 @@ INVALIDPARAMETERVALUE_PARAM = 'InvalidParameterValue.Param'
 # ProtocolType input parameter error
 INVALIDPARAMETERVALUE_PROTOCOLTYPE = 'InvalidParameterValue.ProtocolType'
 
-# 
+# Cron expression of the scheduled action already exists
 INVALIDPARAMETERVALUE_PROVISIONTRIGGERCRONCONFIGDUPLICATE = 'InvalidParameterValue.ProvisionTriggerCronConfigDuplicate'
 
-# 
+# TriggerName input parameter error
 INVALIDPARAMETERVALUE_PROVISIONTRIGGERNAME = 'InvalidParameterValue.ProvisionTriggerName'
 
-# 
+# TriggerName already exists
 INVALIDPARAMETERVALUE_PROVISIONTRIGGERNAMEDUPLICATE = 'InvalidParameterValue.ProvisionTriggerNameDuplicate'
 
-# 
+# ProvisionType input parameter error
 INVALIDPARAMETERVALUE_PROVISIONTYPE = 'InvalidParameterValue.ProvisionType'
 
 # The `PublicNetConfig` parameter is invalid.
@@ -404,10 +416,10 @@ INVALIDPARAMETERVALUE_TEMPCOSOBJECTNAME = 'InvalidParameterValue.TempCosObjectNa
 # The value of `TraceEnable` is invalid. Please modify and try again.
 INVALIDPARAMETERVALUE_TRACEENABLE = 'InvalidParameterValue.TraceEnable'
 
-# 
+# TriggerCronConfig input parameter error
 INVALIDPARAMETERVALUE_TRIGGERCRONCONFIG = 'InvalidParameterValue.TriggerCronConfig'
 
-# 
+# The interval of triggering specified in TriggerCronConfig is smaller than the specified value.
 INVALIDPARAMETERVALUE_TRIGGERCRONCONFIGTIMEINTERVAL = 'InvalidParameterValue.TriggerCronConfigTimeInterval'
 
 # TriggerDesc error.
@@ -416,7 +428,7 @@ INVALIDPARAMETERVALUE_TRIGGERDESC = 'InvalidParameterValue.TriggerDesc'
 # TriggerName error.
 INVALIDPARAMETERVALUE_TRIGGERNAME = 'InvalidParameterValue.TriggerName'
 
-# 
+# TriggerProvisionedConcurrencyNum input parameter error
 INVALIDPARAMETERVALUE_TRIGGERPROVISIONEDCONCURRENCYNUM = 'InvalidParameterValue.TriggerProvisionedConcurrencyNum'
 
 # Type error.
@@ -482,10 +494,10 @@ LIMITEXCEEDED_NAMESPACE = 'LimitExceeded.Namespace'
 # Offset exceeds the upper limit.
 LIMITEXCEEDED_OFFSET = 'LimitExceeded.Offset'
 
-# 
+# The number of provisioned concurrency specified for the scheduled action is too large.
 LIMITEXCEEDED_PROVISIONTRIGGERACTION = 'LimitExceeded.ProvisionTriggerAction'
 
-# 
+# The interval of triggering is too short.
 LIMITEXCEEDED_PROVISIONTRIGGERINTERVAL = 'LimitExceeded.ProvisionTriggerInterval'
 
 # The number of retry attempts in the async retry configuration of the function exceeds the limit.
@@ -593,6 +605,9 @@ RESOURCENOTFOUND_GETCFSMOUNTINSERROR = 'ResourceNotFound.GetCfsMountInsError'
 # An error occurred while getting the CFS information.
 RESOURCENOTFOUND_GETCFSNOTMATCH = 'ResourceNotFound.GetCfsNotMatch'
 
+# Failed to find the specified ImageConfig. Please create it first.
+RESOURCENOTFOUND_IMAGECONFIG = 'ResourceNotFound.ImageConfig'
+
 # The layer does not exist.
 RESOURCENOTFOUND_LAYER = 'ResourceNotFound.Layer'
 
